import csv
import os

JAHRE = ["2017", "2018", "2019"]
PFAD = "Daten"
ENDUNG = ".csv"


def csv_auslesen(pfad):
    daten = []
    with open(pfad) as csvfile:
        reader = csv.DictReader(csvfile, delimiter=";")
        for data in reader:
            if data["Prüflingsnummer"]:
                daten.append((data["Standortname"], data["Prüflingsnummer"], data["Bestanden"]))
    return daten


def anzahl_geraete_bestimmen(daten, jahr):
    geraete = []

    for data in daten:
        if not data[1] in geraete:
            geraete.append(data[1])

    print(f"Vorhandene Geräte im {jahr}: {len(geraete)}")
    # print(f"Vorhandene Geräte im {jahr}: {len(set([d[1] for d in daten]))}")


def fehlerquote_bestimmen(daten, jahr):
    geraete = {}
    for data in daten:
        if not data[1] in geraete:
            if data[2] == "ja":
                geraete[data[1]] = True
            elif data[2] == "nein":
                geraete[data[1]] = False
        else:
            if data[2] == "nein":
                geraete[data[1]] = False
    gesamt = len(geraete)
    fehler = 0
    for status in geraete.values():
        if not status:
            fehler += 1

    print(f"Fehlerquote im Jahr {jahr}: {round(fehler / gesamt * 100, 2)}%")


def main():
    for jahr in JAHRE:
        pfad = os.path.join(PFAD, f"{jahr}{ENDUNG}")
        daten = csv_auslesen(pfad)
        anzahl_geraete_bestimmen(daten, jahr)
        fehlerquote_bestimmen(daten, jahr)
        print()


if __name__ == "__main__":
    main()

